import os
class Calc:
    def __init__(self):
        pass
    def sum(self,a,b):
        return a+b
    def subtract(self,a,b):
        return a-b 
    def multiply(self,a,b):
        return a*b
    def divide(self,a,b):
        return a/b

calculator = Calc()