from setuptools import setup

setup(
    name='useless_calc',
    url='https://github.com/jagadeesh-r1/calculate_silly',
    author='Jagadeesh Reddy',
    author_email='mail4jagadeeshreddy@gmail.com',
    packages=['Calculate'],
    version='0.0.1',
    license='GNU General Public License v3.0',
    description='dont use this.',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown'
)